#!/usr/bin/env python

"""
Document format translators.

Copyright (C) 2017, 2018, 2023 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.translators.manifest import translators

# Top-level functions.

def get_translator(name, doctype=None):

    """
    Return a translator class producing nodes whose document type has the given
    'name'. If 'doctype' is indicated, obtain a translator class specific to
    that document type. Otherwise, a general translator for Moin content is
    obtained.
    """

    return translators["%s.%s" % (name, doctype or "moin")]

def make_translator(metadata, doctype=None):

    """
    Return a translator instance using the given 'metadata' and optional output
    'doctype'.
    """

    return metadata.get_translator(doctype)

def translate(doc, translator):

    "Translate 'doc' using the given 'translator' instance."

    return doc.visit(translator)

# vim: tabstop=4 expandtab shiftwidth=4
